summaryrefslogtreecommitdiff
path: root/Source/Core
diff options
context:
space:
mode:
authorMat M <mathew1800@gmail.com>2017-01-05 14:22:54 -0500
committerGitHub <noreply@github.com>2017-01-05 14:22:54 -0500
commit189e5f87fbc050f9d043b159efa505d03ba3024f (patch)
tree7fa3f2989b988b203140830142d4f78cf536f35d /Source/Core
parent41101be545d4e2f10c77503a14b5236c870428ac (diff)
parent6d195f3d651644e6a3bbf71429cc09ec825a9531 (diff)
Merge pull request #4612 from PEmu1/memcard-menu
Don't Use Abbreviation for "Memory Card"
Diffstat (limited to 'Source/Core')
-rw-r--r--Source/Core/Core/HW/GCMemcard.cpp4
-rw-r--r--Source/Core/DolphinWX/MainMenuBar.cpp2
-rw-r--r--Source/Core/DolphinWX/MemcardManager.cpp17
-rw-r--r--Source/Core/DolphinWX/NetPlay/NetWindow.cpp2
4 files changed, 13 insertions, 12 deletions
diff --git a/Source/Core/Core/HW/GCMemcard.cpp b/Source/Core/Core/HW/GCMemcard.cpp
index 1aaf1ca369..be8ba4d249 100644
--- a/Source/Core/Core/HW/GCMemcard.cpp
+++ b/Source/Core/Core/HW/GCMemcard.cpp
@@ -32,7 +32,7 @@ GCMemcard::GCMemcard(const std::string& filename, bool forceCreation, bool shift
{
if (!forceCreation)
{
- if (!AskYesNoT("\"%s\" does not exist.\n Create a new 16MB Memcard?", filename.c_str()))
+ if (!AskYesNoT("\"%s\" does not exist.\n Create a new 16MB Memory Card?", filename.c_str()))
return;
shift_jis =
AskYesNoT("Format as Shift JIS (Japanese)?\nChoose no for Windows-1252 (Western)");
@@ -190,7 +190,7 @@ GCMemcard::GCMemcard(const std::string& filename, bool forceCreation, bool shift
}
else
{
- PanicAlertT("Failed to read block %u of the save data\nMemcard may be truncated\nFile "
+ PanicAlertT("Failed to read block %u of the save data\nMemory card may be truncated\nFile "
"position: 0x%" PRIx64,
i, mcdFile.Tell());
m_valid = false;
diff --git a/Source/Core/DolphinWX/MainMenuBar.cpp b/Source/Core/DolphinWX/MainMenuBar.cpp
index 679c6821b6..9efdd24036 100644
--- a/Source/Core/DolphinWX/MainMenuBar.cpp
+++ b/Source/Core/DolphinWX/MainMenuBar.cpp
@@ -212,7 +212,7 @@ wxMenu* MainMenuBar::CreateToolsMenu() const
wiimote_menu->AppendCheckItem(IDM_CONNECT_BALANCEBOARD, _("Connect Balance Board"));
auto* const tools_menu = new wxMenu;
- tools_menu->Append(IDM_MEMCARD, _("&Memcard Manager (GC)"));
+ tools_menu->Append(IDM_MEMCARD, _("&Memory Card Manager (GC)"));
tools_menu->Append(IDM_IMPORT_SAVE, _("Import Wii Save..."));
tools_menu->Append(IDM_EXPORT_ALL_SAVE, _("Export All Wii Saves"));
tools_menu->Append(IDM_CHEATS, _("&Cheat Manager"));
diff --git a/Source/Core/DolphinWX/NetPlay/NetWindow.cpp b/Source/Core/DolphinWX/NetPlay/NetWindow.cpp
index 596de8676d..ff5e5a368c 100644
--- a/Source/Core/DolphinWX/NetPlay/NetWindow.cpp
+++ b/Source/Core/DolphinWX/NetPlay/NetWindow.cpp
@@ -256,7 +256,7 @@ wxSizer* NetPlayDialog::CreateBottomGUI(wxWindow* parent)
padbuf_spin->Bind(wxEVT_SPINCTRL, &NetPlayDialog::OnAdjustBuffer, this);
padbuf_spin->SetMinSize(WxUtils::GetTextWidgetMinSize(padbuf_spin));
- m_memcard_write = new wxCheckBox(parent, wxID_ANY, _("Write to memcards/SD"));
+ m_memcard_write = new wxCheckBox(parent, wxID_ANY, _("Write to memory cards/SD"));
bottom_szr->Add(m_start_btn, 0, wxALIGN_CENTER_VERTICAL);
bottom_szr->Add(buffer_lbl, 0, wxALIGN_CENTER_VERTICAL | wxLEFT, space5);
diff --git a/Source/Core/DolphinWX/MemcardManager.cpp b/Source/Core/DolphinWX/MemcardManager.cpp
index 0ba2d149ac..e15d557957 100644
--- a/Source/Core/DolphinWX/MemcardManager.cpp
+++ b/Source/Core/DolphinWX/MemcardManager.cpp
@@ -165,7 +165,7 @@ bool CMemcardManager::SaveSettings()
void CMemcardManager::CreateGUIControls()
{
// Create the controls for both memcards
const int space5 = FromDIP(5);
const char* ARROW[2] = {"<-", "->"};
@@ -286,7 +286,7 @@ void CMemcardManager::ChangePath(int slot)
if (!m_MemcardPath[SLOT_A]->GetPath().CmpNoCase(m_MemcardPath[SLOT_B]->GetPath()))
{
if (m_MemcardPath[slot]->GetPath().length())
- wxMessageBox(_("Memcard already opened"));
+ wxMessageBox(_("Memory card already opened"));
}
else
{
@@ -423,7 +423,7 @@ bool CMemcardManager::CopyDeleteSwitch(u32 error, int slot)
}
break;
case NOMEMCARD:
- WxUtils::ShowErrorDialog(_("File is not recognized as a memcard"));
+ WxUtils::ShowErrorDialog(_("File is not recognized as a memory card"));
break;
case OPENFAIL:
WxUtils::ShowErrorDialog(_("File could not be opened\nor does not have a valid extension"));
@@ -447,7 +447,7 @@ bool CMemcardManager::CopyDeleteSwitch(u32 error, int slot)
WxUtils::ShowErrorDialog(_("The save you are trying to copy has an invalid file size."));
break;
case TITLEPRESENT:
- WxUtils::ShowErrorDialog(_("Memcard already has a save for this title."));
+ WxUtils::ShowErrorDialog(_("Memory card already has a save for this title."));
break;
case SAVFAIL:
WxUtils::ShowErrorDialog(
@@ -471,7 +471,7 @@ bool CMemcardManager::CopyDeleteSwitch(u32 error, int slot)
case DELETE_FAIL:
WxUtils::ShowErrorDialog(
_("Order of files in the File Directory do not match the block order\n"
- "Right click and export all of the saves,\nand import the saves to a new memcard\n"));
+ "Right click and export all of the saves,\nand import the saves to a new memory card\n"));
break;
default:
WxUtils::ShowErrorDialog(_("Unknown memory card error"));
@@ -594,7 +594,7 @@ void CMemcardManager::CopyDeleteClick(wxCommandEvent& event)
int answer = wxMessageBox(
wxString::Format(
_("Warning: This will overwrite any existing saves that are in the folder:\n"
- "%s\nand have the same name as a file on your memcard\nContinue?"),
+ "%s\nand have the same name as a file on your memory card\nContinue?"),
path1.c_str()),
_("Warning"), wxYES_NO);
if (answer == wxYES)
@@ -817,7 +817,8 @@ void CMemcardManager::CMemcardListCtrl::OnRightClick(wxMouseEvent& event)
SetItemState(item, wxLIST_STATE_FOCUSED, wxLIST_STATE_FOCUSED);
int slot = GetId() - ID_MEMCARDLIST_A;
- popupMenu.Append(ID_COPYFROM_A + slot, wxString::Format(_("Copy to Memcard %c"), 'B' - slot));
+ popupMenu.Append(ID_COPYFROM_A + slot,
+ wxString::Format(_("Copy to Memory Card %c"), 'B' - slot));
popupMenu.Append(ID_DELETE_A + slot, _("Delete Save"));
popupMenu.Append(ID_SAVEIMPORT_A + slot, _("Import Save"));
popupMenu.Append(ID_SAVEEXPORT_A + slot, _("Export Save"));
@@ -831,7 +832,7 @@ void CMemcardManager::CMemcardListCtrl::OnRightClick(wxMouseEvent& event)
popupMenu.Append(ID_PREVPAGE_A + slot, _("Previous Page"));
popupMenu.Append(ID_NEXTPAGE_A + slot, _("Next Page"));
popupMenu.Append(ID_MEMCARDPATH_A + slot,
- wxString::Format(_("Set as default Memcard %c"), 'A' + slot));
+ wxString::Format(_("Set as default Memory Card %c"), 'A' + slot));
popupMenu.AppendCheckItem(ID_USEPAGES, _("Enable pages"));
popupMenu.FindItem(ID_PREVPAGE_A + slot)->Enable(prevPage && __mcmSettings.usePages);
@@ -165,7 +165,7 @@ bool CMemcardManager::SaveSettings()
void CMemcardManager::CreateGUIControls()
{
- // Create the controls for both memcards
+ // Create the controls for both memory cards
const int space5 = FromDIP(5);
const char* ARROW[2] = {"<-", "->"};